==> libreoffice-4.4.0.3.tar.xz: libreoffice-4.4.0.3/vcl/source/helper/evntpost.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <sal/config.h>

#include <tools/debug.hxx>
#include <vcl/evntpost.hxx>
#include <vcl/svapp.hxx>

namespace vcl
{

EventPoster::EventPoster( const Link& rLink )
    : m_aLink(rLink)
{
    m_nId = 0;
}

EventPoster::~EventPoster()
{
    DBG_TESTSOLARMUTEX();
    if ( m_nId )
        Application::RemoveUserEvent( m_nId );
}

void EventPoster::Post( UserEvent* pEvent )

{
    DBG_TESTSOLARMUTEX();
    m_nId = Application::PostUserEvent( ( LINK( this, EventPoster, DoEvent_Impl ) ), pEvent );
}

IMPL_LINK( EventPoster, DoEvent_Impl, UserEvent*, pEvent )
{
    DBG_TESTSOLARMUTEX();
    m_nId = 0;
    m_aLink.Call( pEvent );
    return 0;
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-5.0.2.2.tar.xz: libreoffice-5.0.2.2/vcl/source/helper/evntpost.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <sal/config.h>

#include <tools/debug.hxx>
#include <vcl/evntpost.hxx>
#include <vcl/svapp.hxx>

namespace vcl
{

EventPoster::EventPoster( const Link<>& rLink )
    : m_aLink(rLink)
{
    m_nId = 0;
}

EventPoster::~EventPoster()
{
    DBG_TESTSOLARMUTEX();
    if ( m_nId )
        Application::RemoveUserEvent( m_nId );
}

void EventPoster::Post( UserEvent* pEvent )

{
    DBG_TESTSOLARMUTEX();
    m_nId = Application::PostUserEvent( ( LINK( this, EventPoster, DoEvent_Impl ) ), pEvent );
}

IMPL_LINK( EventPoster, DoEvent_Impl, UserEvent*, pEvent )
{
    DBG_TESTSOLARMUTEX();
    m_nId = 0;
    m_aLink.Call( pEvent );
    return 0;
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
